@@ -2,7 +2,7 @@
 /**
  * Test the incoming filter class for its load behaviour..
  *
- * $Horde: framework/Kolab_Filter/test/Horde/Kolab/Filter/LoadTest.php,v 1.6.2.2 2009-02-24 11:17:40 wrobel Exp $
+ * $Horde: framework/Kolab_Filter/test/Horde/Kolab/Filter/LoadTest.php,v 1.6.2.3 2010/04/15 13:23:20 wrobel Exp $
  *
  * @package Horde_Kolab_Filter
  */
@@ -19,7 +19,7 @@ require_once 'Horde/Kolab/Filter/Incoming.php';
 /**
  * Test the incoming filter load.
  *
- * $Horde: framework/Kolab_Filter/test/Horde/Kolab/Filter/LoadTest.php,v 1.6.2.2 2009-02-24 11:17:40 wrobel Exp $
+ * $Horde: framework/Kolab_Filter/test/Horde/Kolab/Filter/LoadTest.php,v 1.6.2.3 2010/04/15 13:23:20 wrobel Exp $
  *
  * Copyright 2008 Klarälvdalens Datakonsult AB
  *
@@ -114,5 +114,6 @@ class Horde_Kolab_Filter_LoadTest extends PHPUnit_Extensions_PerformanceTestCase
             $parser->parse($inh, 'drop');
 
         }
+	unlink($tmpfile);
     }
 }
